#
# spec file for package kubetui
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           kubetui
Version:        1.5.3
Release:        1.1
Summary:        A terminal UI for Kubernetes
License:        MIT
URL:            https://github.com/sarub0b0/kubetui
Source0:        kubetui-%{version}.tar.zst
Source1:        vendor.tar.zst
Source2:        cargo_config
BuildRequires:  cargo-packaging
BuildRequires:  zstd

%description

Kubetui is a terminal user interface (TUI) tool designed for monitoring Kubernetes resources.
It provides an easy-to-use interface for developers and operators to access important information about their applications and infrastructure.

%prep
%autosetup -a1
install -D -m 0644 %{SOURCE2} .cargo/config

%build
%{cargo_build}

%install
%{cargo_install}

%files
%license LICENSE
%doc README.md
%{_bindir}/%{name}

%changelog
* Wed Jul 24 2024 ekr59uv25@gmail.com
- Update to version 1.5.3:
  * fix(deps): update rust crate kube to 0.93.0
  * chore(deps): update rust crate mockall to 0.13.0
  * chore(deps): lock file maintenance
  * fix(deps): update rust crate thiserror to v1.0.63
  * chore(deps): update rust crate tokio to v1.38.1
  * fix(deps): update rust crate bytes to v1.6.1
  * fix(deps): update rust crate thiserror to v1.0.62
  * fix(deps): update rust crate clap to v4.5.9
  * fix(deps): update rust crate async-trait to v0.1.81
  * docs: Add keybinding for toggling split layout direction
  * feat(ui): Add support for toggling split layout direction
  * fix(deps): update rust crate serde to v1.0.204
  * fix(deps): update rust crate serde_json to v1.0.120
  * fix(kube/log): prevent removal of leading spaces in container logs
  * fix(deps): update rust crate serde_json to v1.0.119
  * chore(render): add error logging in window action
  * refactor(kube/store): clippy needless borrow
  * refactor(kube/secret): replaced with the `?` operator
  * chore(ui): suppress warnings for unused code in widget.rs
  * chore(apis): allow dead code in kube apis module
  * refactor(related_resources): simplify related resource structs
  * refactor(v1_table): replace ToString with Display for Value
  * fix(deps): update rust crate clap to v4.5.8
  * fix(deps): update rust crate log to v0.4.22
  * chore(deps): lock file maintenance
  * fix(ui): Simplify generate_spans_line generation and tests
  * fix(ui): Update crossterm usage to ratatui's crossterm
  * fix(deps): update rust crate ratatui to 0.27.0
  * fix(deps): update rust crate serde_json to v1.0.118
  * fix(deps): update rust crate strum to v0.26.3
  * fix(deps): update rust crate kube to v0.92.1
  * chore(deps): lock file maintenance
  * chore(deps): update actions/checkout digest to 692973e
  * fix(deps): update rust crate kube to 0.92.0
  * fix(deps): update rust crate clap to v4.5.7
  * fix(deps): update all dependencies
  * chore(deps): lock file maintenance
  * fix(deps): update rust crate clap to v4.5.6
  * fix(deps): update rust crate clap to v4.5.5
  * fix(deps): update rust crate unicode-width to v0.1.13
  * test(network): fix kube network description tests
  * chore(deps): update rust crate rstest to 0.21.0
  * chore(deps): update rust crate tokio to v1.38.0
  * chore(deps): update rust crate rstest to 0.20.0
  * fix(deps): update rust crate serde to v1.0.203
  * chore(deps): lock file maintenance
  * fix(deps): update rust crate ratatui to v0.26.3
  * chore(deps): update actions/checkout digest to a5ac7e5
  * docs: add Chocolatey installation note
  * fix(deps): update rust crate anyhow to v1.0.86
  * fix(deps): update rust crate anyhow to v1.0.85
  * fix(deps): update rust crate thiserror to v1.0.61
* Thu May 16 2024 ekr59uv25@gmail.com
- Update to version 1.5.2:
  * (experimental) Support Gateway API (only Gateway and HTTPRoute)
  * fix(ui/table): ensure filter form displays when items are empty
* Wed Apr 24 2024 dcermak@suse.com
- Update to version 1.5.1:
  * Release version 1.5.1
  * Bump deps including rustls (fixes bsc#1223225 - CVE-2024-32650)
* Sun Jan 28 2024 Kosei Hashimoto <ekr59uv25@gmail.com>
- Initial spec for kubetui 1.5.0
